@@ -4,7 +4,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     01/10/2000
-## RCS-ID:      $Id: Wx.pm 2912 2010-04-26 19:59:53Z mbarbon $
+## RCS-ID:      $Id: Wx.pm 2940 2010-07-06 19:41:40Z mbarbon $
 ## Copyright:   (c) 2000-2010 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -21,7 +21,7 @@ use vars qw(@ISA $VERSION $XS_VERSION $AUTOLOAD @EXPORT_OK %EXPORT_TAGS
 $_msw = 1; $_gtk = 2; $_motif = 3; $_mac = 4; $_x11 = 5;
 
 @ISA = qw(Exporter);
-$VERSION = '0.9701_02';
+$VERSION = '0.9702_01';
 $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -165,11 +165,6 @@ eval( "sub wxGTK() { $_platform == $_gtk }" );
 eval( "sub wxMAC() { $_platform == $_mac }" );
 eval( "sub wxX11() { $_platform == $_x11 }" );
 
-# Mac OS X warning
-if( wxMAC() && $^X !~ m{/wxPerl\.app/} && !$ENV{HARNESS_ACTIVE} ) {
-    warn "On Mac OS X please run scripts with the 'wxPerl' interpreter\n";
-}
-
 require Wx::App;
 require Wx::Event;
 require Wx::Locale;
