@@ -4,8 +4,8 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: helpers.h 2526 2009-02-07 14:35:21Z mbarbon $
-// Copyright:   (c) 2000-2009 Mattia Barbon
+// RCS-ID:      $Id: helpers.h 2934 2010-07-04 08:44:12Z mbarbon $
+// Copyright:   (c) 2000-2010 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
@@ -416,16 +416,14 @@ SV* FUNCPTR( wxPliVirtualCallback_CallCallback )
     ( pTHX_ const wxPliVirtualCallback* cb, I32 flags,
       const char* argtypes, ... );
 
-// defined in overload.cpp
+// used in overload.cpp
 struct wxPliPrototype
 {
-    wxPliPrototype( const char** const t,
-                    const unsigned char* const a,
-                    const size_t c )
-      : tnames( t ), args( a ), count( c ) { }
+    wxPliPrototype( const char** const proto,
+                    const size_t proto_size )
+      : args( proto ), count( proto_size ) { }
 
-    const char** const tnames;
-    const unsigned char* const args;
+    const char** const args;
     const size_t count;
 };
 
@@ -435,6 +433,8 @@ bool wxPli_match_arguments( pTHX_ const wxPliPrototype& prototype,
 bool FUNCPTR( wxPli_match_arguments_skipfirst )( pTHX_ const wxPliPrototype& p,
                                                  int required,
                                                  bool allow_more );
+void FUNCPTR( wxPli_overload_error )( pTHX_ const char* function,
+                                      wxPliPrototype* prototypes[] );
 
 #define WXPLI_BOOT_ONCE_( name, xs ) \
 bool name##_booted = false; \
@@ -525,6 +525,8 @@ struct wxPliHelpers
     void (* m_wxPli_objlist_push )( pTHX_ const wxList& objs );
     wxPliOutputStream* ( * m_wxPliOutputStream_ctor )( SV* );
     void (* m_wxPli_stringarray_push )( pTHX_ const wxArrayString& );
+    void (* m_wxPli_overload_error )( pTHX_ const char* function,
+                                      wxPliPrototype* prototypes[] );
 };
 
 #if wxPERL_USE_THREADS
@@ -567,7 +569,8 @@ wxPliHelpers name = { &wxPli_sv_2_object, \
  wxDEFINE_PLI_HELPER_THREADS() \
  wxDEFINE_PLI_HELPER_UNICODE() \
  &wxPli_av_2_arrayint, &wxPli_set_events, &wxPli_av_2_arraystring, \
- &wxPli_objlist_push, &wxPliOutputStream_ctor, &wxPli_stringarray_push \
+ &wxPli_objlist_push, &wxPliOutputStream_ctor, &wxPli_stringarray_push, \
+ &wxPli_overload_error \
  }
 
 #if NEEDS_PLI_HELPERS_STRUCT()
@@ -612,6 +615,7 @@ wxPliHelpers name = { &wxPli_sv_2_object, \
   wxPli_objlist_push = name->m_wxPli_objlist_push; \
   wxPliOutputStream_ctor = name->m_wxPliOutputStream_ctor; \
   wxPli_av_2_stringarray = name->m_wxPli_av_2_stringarray; \
+  wxPli_overload_error = name->m_wxPli_overload_error; \
   WXPLI_INIT_CLASSINFO();
 
 #else
