@@ -5,7 +5,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     11/08/2002
-// RCS-ID:      $Id: overload.h 2737 2010-01-03 19:50:07Z mbarbon $
+// RCS-ID:      $Id: overload.h 2934 2010-07-04 08:44:12Z mbarbon $
 // Copyright:   (c) 2002, 2004, 2006-2007, 2010 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -13,6 +13,17 @@
 
 #include "cpp/ovl_const.h"
 
+#define wxPliOvlarr   ((const char*)1)
+#define wxPliOvlbool  ((const char*)2)
+#define wxPliOvlnum   ((const char*)3)
+#define wxPliOvlstr   ((const char*)4)
+#define wxPliOvlwist  ((const char*)5)
+#define wxPliOvlwost  ((const char*)6)
+#define wxPliOvlwpoi  ((const char*)7)
+#define wxPliOvlwpos  ((const char*)8)
+#define wxPliOvlwsiz  ((const char*)9)
+#define wxPliOvlzzz   ((const char*)10)
+
 #define BEGIN_OVERLOAD() \
     PUSHMARK(MARK); \
     int count; \
@@ -25,8 +36,11 @@
         require_pv( "Carp" ); \
         const char* argv[3]; argv[0] = msg; argv[1] = #FUNCTION; argv[2] = 0; \
         call_argv( "Carp::croak", G_VOID|G_DISCARD, (char**) argv ); \
-    } \
-    /* POPMARK; */
+    }
+
+#define END_OVERLOAD_MESSAGE( FUNCTION, PROTOTYPES )       \
+    else \
+        wxPli_overload_error( aTHX_ #FUNCTION, PROTOTYPES );
 
 #define REDISPATCH( NEW_METHOD_NAME ) \
     count = call_method( #NEW_METHOD_NAME, GIMME_V ); SPAGAIN
@@ -72,3 +86,7 @@
     else if( wxPli_match_arguments( aTHX_ PROTO,       \
                                     REQUIRED, true ) ) \
         { REDISPATCH_FUNCTION( METHOD ); }
+
+#define MATCH_VOIDM_REDISP_FUNCTION( METHOD ) \
+    else if( items == 0 ) \
+        { REDISPATCH_FUNCTION( METHOD ); }
